<?php
namespace SupplyTek\Services;

/**
 * Login Model
 * 
 * Connects to the Database to handle queries 
 * related to login processes. 
 *  
 * @author Rômulo Alves Lousada
 */
class LoginService
{
    protected $entityManager;
    protected $connection;

    /**
     * Class constructor
     * 
     * Initialize an object's properties upon creation of the object.
     * 
     * @param object $entityManager Object to manage database connection and queries
     * 
     * @return void
     * 
     * @access public
     * @author Rômulo Alves Lousada
     */
    public function __construct($entityManager)
    {
        $this->entityManager = $entityManager;
        $this->connection = $entityManager->getConnection();
    }

    /**
     * Start a transaction on database
     * 
     * @return void
     * 
     * @access public
     * @author Rômulo Alves Lousada
     */
    public function beginTransaction()
    {
        $this->entityManager->beginTransaction();
    }
    
    /**
     * Commit a transaction on database
     * 
     * @return void
     * 
     * @access public
     * @author Rômulo Alves Lousada
     */
    public function commitTransaction()
    {
        $this->entityManager->commit();
    }
    
    /**
     * Rollback a transaction on database
     * 
     * @return void
     * 
     * @access public
     * @author Rômulo Alves Lousada
     */
    public function rollbackTransaction()
    {
        $this->entityManager->rollBack();
    }

    /**
     * Insert new row on CONTROLSENHA
     * 
     * Inserts a new row on CONTROLSENHA table to inform
     * if the "IDATUCTRLSENHA" of the record saved is one of:
     * 
     * R - The password was just resetted by the system
     * S - The password was changed by the user
     *
     * @param array $params Array with parameters needed for the insert.
     *
     * @return void
     *
     * @access public
     * @author Rômulo Alves Lousada
     */
    public function insertControl($params)
    {
        $sql = "INSERT INTO CONTROLSENHA
                (
                    NRORGINCLUSAO, 
                    DTINCLUSAO, 
                    CDOPERINCLUSAO, 
                    CDOPERADOR, 
                    DTALTSENHA,
                    CDSENHALT, 
                    CDSENHALTWEB, 
                    IDATUCTRLSENHA, 
                    NRORG, 
                    DTULTATU, 
                    NRORGULTATU, 
                    CDOPERULTATU
                )
                VALUES 
                (
                    :ORG_ID, 
                    SYSDATE, 
                    :OPERATOR_ID, 
                    :OPERATOR_ID, 
                    SYSDATE,
                    :PASSWORD_DELPHI, 
                    :PASSWORD_WEB, 
                    :UPDATE_CTRLSENHA_ID, 
                    :ORG_ID, 
                    SYSDATE, 
                    :ORG_ID, 
                    :OPERATOR_ID
                )";
        
        $params = array(
            "ORG_ID" => $params["ORG_ID"],
            "OPERATOR_ID" => $params["OPERATOR_ID"],
            "PASSWORD_DELPHI" => $params["PASSWORD_DELPHI"],
            "PASSWORD_WEB" => $params["PASSWORD_WEB"],
            "UPDATE_CTRLSENHA_ID" => $params["UPDATE_CTRLSENHA_ID"]
        );

        $std = $this->connection->prepare($sql);
        
        $std->execute($params);
    }
    
    /**
     * Update row on OPERADOR
     *
     * Updates an existing operator row on the table, overwriting the
     * user existing passwords with a new generated and encrypted ones.
     * 
     * @param array $params Array with parameters needed for the update.
     *
     * @return void
     *
     * @access public
     * @author Rômulo Alves Lousada
     */
    public function updatePassword($params)
    {
        $sql = "UPDATE 
                    OPERADOR
                SET 
                    CDSENHOPER = :PASSWORD_DELPHI,
                    CDSENHAOPERWEB = :PASSWORD_WEB,
                    DTULTATU = SYSDATE,
                    IDSTATUSENHA = 'A'
                WHERE 
                    NRORG = :ORG_ID
                    AND CDOPERADOR = :OPERATOR_ID";
        
        $params = array(
            "ORG_ID" => $params["ORG_ID"],
            "OPERATOR_ID" => $params["OPERATOR_ID"],
            "PASSWORD_DELPHI" => $params["PASSWORD_DELPHI"],
            "PASSWORD_WEB" => $params["PASSWORD_WEB"]
        );

        $std = $this->connection->prepare($sql);
        
        $std->execute($params);
    }
}